/*	---------------------------------------------------
 * 	Script:		utilities.js				Version:2.0
 * 	Author:		Neil Thomas
 * 	Last Edit:	14th Feb 2023
 * 	Based on:	/js/utilFTPnow.html & util_reloaddayfile.html
 * 			By:	Mark Crossley
 *		Edited:	2022/07/28 20:43:08 & 2022/07/28 20:44:09
 * 	--------------------------------------------------*/

$( function() {
    //  Correct 'on Document ready' function structure
    //  Allocate click event to 'Start FTP' button
    $('#startFTP').click( function( event ) {
        console.log("Function'startFTP' called");
        $('#ftpStatus').text('');
        $.post(
            "/api/utils/ftpnow.json",
            '{"dailygraphs":' + $('#dailygraphs').prop('checked') +
            ',"noaa":' + $('#noaa').prop('checked') +
            ',"graphs":' + $('#graphs').prop('checked') + '}',
        ).done(function (response) {
            $('#ftpStatus').text(response);
        }).fail(function (jqXHR, response) {
            $('#ftpStatus').text(response);
        });
        timeOut( 'ftpStatus' );
    });
    
    //  Allocate click event to 'Reload dayfile' button
    $('#reLoad').click( function( event ) {
        console.log("");
        $('#dayFileStatus').text('Reloading dayfile.');
        $.ajax({ 
            url: '/api/utils/reloaddayfile',
            dataType: 'text'
        })
        .done( function( response ) {
            $('#datFileStatus').text( response );
            timeOut( 'dayFileStatus' );
        })
        .fail( function( jqXHR, response ) {
            $('#dayFileStatus').text( response );
        });
        
    });
    //  Allocate click event to 'Purge MySQL' button
    $('#purgeMySQL').click( function( event ) {
        $('#purgeStatus').text('Purging MySQL queue');
        $.ajax({
            url: '/api/utils/purgemysql',
            dataTyle: 'text'
        })
        .done( function( response ) {
            $('#purgeStatus').text( response );
            $('#sqlcache').DataTable().ajax.reload();
        })
        .fail( function( jqXHR, response ) {
            $('#purgeStatus').text(response);
            $('#sqlcache').DataTable().ajax.reload();
        })
    });
    
    var columnDefs = [{
        title: "Key",
        readonly: true
    }, {
        title: 'MySQL Statement',
        type: 'textarea'
    }];

    var myTable = $('#sqlcache').DataTable({
        pagingType: 'input',
        processing: true,
        serverSide: true,
        searching: true,
        searchDelay: 750,
        ordering: false,
        pageLength: 10,
        lengthMenu: [10,20,50,100],
        autoWidth: false,
        rowId: 'key',
        ajax: {
            url: '/api/data/mysqlcache.json',
            data: function (data) {
                delete data.columns;
            }
        },
        columns: columnDefs,
        dom: '<"top"Bfip<"clear">>t<"bottom"fip<"clear">>',
        select: 'os',
        responsive: false,
        altEditor: true,     // Enable altEditor
        buttons: [
            {
                extend: 'selected', // Bind to Selected row
                text: 'Edit',
                name: 'edit'        // do not change name
            },
            {
                extend: 'selected', // Bind to Selected row
                text: 'Delete',
                name: 'delete'      // do not change name
            },
            {
                text: 'Refresh',
                name: 'refresh'      // do not change name
            },
            'pageLength'
        ],
        language: {
            altEditor: {
                modalClose: 'Close',
                edit: {
                    title: 'Edit record',
                    button: 'Save'
                }
            }
        },
        onEditRow: function(datatable, rowdata, success, error) {
            var selector = datatable.modal_selector;
            $(selector + ' .modal-body .alert').remove();

            $.ajax({
                url: '/api/edit/mysqlcache',
                type: 'POST',
                data: formatRequestSingle('Edit', rowdata),
                success: success,
                error: function(response, status, more) {
                    // Output the error message
                    var selector = datatable.modal_selector;
                    $(selector + ' .modal-body .alert').remove();
                    var message = '<div class="alert alert-danger" role="alert">' +
                    '<strong>' + datatable.language.error.label + '</strong> ';
                    for (var key in response.responseJSON.errors) {
                        message += response.responseJSON.errors[key][0];
                    }
                    message +='</div>';
                    $(selector + ' .modal-body').append(message);

                    // error 501 means MySQL failed but file update was OK
                    if (response.status == 501) {
                        // We have updated the dayfile data, so update the form
                        datatable.s.dt.row(response.responseJSON.data[0]).data(response.responseJSON.data);
                        datatable.s.dt.draw('page');
                    }
                }
            });
        },
        onDeleteRow: function(datatable, rowdata, success, error) {
            $.ajax({
                url: '/api/edit/mysqlcache',
                type: 'POST',
                data: formatRequestMulti('Delete', rowdata),
                success: success,
                error: function(response, status, more) {
                    // Output the error message
                    var selector = datatable.modal_selector;
                    $(selector + ' .modal-body .alert').remove();
                    var message = '<div class="alert alert-danger" role="alert">' +
                    '<strong>' + datatable.language.error.label + '</strong> ';
                    respJson = JSON.parse(response.responseText);
                    for (var key in respJson.errors) {
                        message += respJson.errors[key][0];
                    }
                    message +='</div>';
                    $(selector + ' .modal-body').append(message);

                    // error 501 means MySQL failed but file update was OK
                    if (response.status == 501) {
                        // We have updated the file data, so update the form
                        datatable.s.dt.reload();
                    }
                }
            });
        }
    });

    function formatRequestSingle(action, rowdata) {
        var data = '[';
        // don't include the first element = line number
        for (key in rowdata) {
            if (!isNaN(key) && key > 0) {
                data += '"' + rowdata[key] + '",';
            }
        }
        // remove trailing comma
        data = data.slice(0, -1);
        data += ']';

        response = '{"action":"' + action + '","keys":[' + rowdata[0] + '],"statements": ' + data + '}';
        return response;
    }

    function formatRequestMulti(action, rowdata) {
        var lines = '[';
        data = '[';
        for (var i = 0; i < rowdata[0].length; i++) {
            lines +=  rowdata.rows(rowdata[0][i]).data()[0][0] + ',';

            // don't include the first element = line number
            data += '"' + rowdata.rows(rowdata[0][i]).data()[0].slice(1).join(',') + '",';
        }
        // remove trailing commas
        lines = lines.slice(0, -1);
        data = data.slice(0, -1);
        lines += ']';
        data += ']';

        response = '{"action":"' + action + '","keys":' + lines + ',"statements": ' + data + '}';
        return response;
    }
    
});


//  --  Timout for status messages        
let timeOut = function(elId) {
    window.setTimeout( function(){$("#" + elId).html("&nbsp;");}, 10000);
};
